@@ -850,11 +850,13 @@ void DvbConfigPage::addHSeparator(const QString &title)
 }
 
 DvbConfigObject::DvbConfigObject(QWidget *parent, QBoxLayout *layout, DvbManager *manager,
-	DvbConfigBase *config_, bool isGen2) : QObject(parent), config(config_)
+	DvbConfigBase *config_, bool isGen2_) : QObject(parent), config(config_)
 {
 	QStringList sources;
 	int sourceIndex = -1;
 
+	isGen2 = isGen2_;
+
 	switch (config->getTransmissionType()) {
 	case DvbConfigBase::DvbC:
 		defaultName = i18n("Cable");
@@ -865,16 +867,21 @@ DvbConfigObject::DvbConfigObject(QWidget *parent, QBoxLayout *layout, DvbManager
 		// handled separately
 		break;
 	case DvbConfigBase::DvbT:
-		sources.append(QLatin1String("AUTO-Normal"));
-		sources.append(QLatin1String("AUTO-Offsets"));
-		sources.append(QLatin1String("AUTO-Australia"));
-		sources.append(QLatin1String("AUTO-Italy"));
-		sources.append(QLatin1String("AUTO-Taiwan"));
 		if (isGen2) {
 			defaultName = i18n("Terrestrial (T2)");
+			sources.append(QLatin1String("AUTO-T2-Normal"));
+			sources.append(QLatin1String("AUTO-T2-Offsets"));
+			sources.append(QLatin1String("AUTO-T2-Australia"));
+			sources.append(QLatin1String("AUTO-T2-Italy"));
+			sources.append(QLatin1String("AUTO-T2-Taiwan"));
 			sources += manager->getScanSources(DvbManager::DvbT2);
 		} else {
 			defaultName = i18n("Terrestrial");
+			sources.append(QLatin1String("AUTO-T-Normal"));
+			sources.append(QLatin1String("AUTO-T-Offsets"));
+			sources.append(QLatin1String("AUTO-T-Australia"));
+			sources.append(QLatin1String("AUTO-T-Italy"));
+			sources.append(QLatin1String("AUTO-T-Taiwan"));
 			sources += manager->getScanSources(DvbManager::DvbT);
 		}
 		sourceIndex = sources.indexOf(config->scanSource);
@@ -950,22 +957,42 @@ void DvbConfigObject::sourceChanged(int index)
 	} else if ((index <= 5) && (config->getTransmissionType() == DvbConfigBase::DvbT)) {
 		nameEdit->setEnabled(true);
 
-		switch (index - 1) {
-		case 0:
-			config->scanSource = QLatin1String("AUTO-Normal");
-			break;
-		case 1:
-			config->scanSource = QLatin1String("AUTO-Offsets");
-			break;
-		case 2:
-			config->scanSource = QLatin1String("AUTO-Australia");
-			break;
-		case 3:
-			config->scanSource = QLatin1String("AUTO-Italy");
-			break;
-		case 4:
-			config->scanSource = QLatin1String("AUTO-Taiwan");
-			break;
+		if (isGen2) {
+			switch (index - 1) {
+			case 0:
+				config->scanSource = QLatin1String("AUTO-T2-Normal");
+				break;
+			case 1:
+				config->scanSource = QLatin1String("AUTO-T2-Offsets");
+				break;
+			case 2:
+				config->scanSource = QLatin1String("AUTO-T2-Australia");
+				break;
+			case 3:
+				config->scanSource = QLatin1String("AUTO-T2-Italy");
+				break;
+			case 4:
+				config->scanSource = QLatin1String("AUTO-T2-Taiwan");
+				break;
+			}
+		} else {
+			switch (index - 1) {
+			case 0:
+				config->scanSource = QLatin1String("AUTO-T-Normal");
+				break;
+			case 1:
+				config->scanSource = QLatin1String("AUTO-T-Offsets");
+				break;
+			case 2:
+				config->scanSource = QLatin1String("AUTO-T-Australia");
+				break;
+			case 3:
+				config->scanSource = QLatin1String("AUTO-T-Italy");
+				break;
+			case 4:
+				config->scanSource = QLatin1String("AUTO-T-Taiwan");
+				break;
+			}
 		}
 	} else {
 		nameEdit->setEnabled(true);
@@ -1024,6 +1051,7 @@ DvbSConfigObject::DvbSConfigObject(QWidget *parent_, QBoxLayout *boxLayout, DvbM
 	configBox->addItem(i18n("DiSEqC Switch"));
 	configBox->addItem(i18n("USALS Rotor"));
 	configBox->addItem(i18n("Positions Rotor"));
+	configBox->addItem(i18n("Disable DiSEqC"));
 	configBox->setCurrentIndex(lnbConfig->configuration);
 	connect(configBox, SIGNAL(currentIndexChanged(int)), this, SLOT(configChanged(int)));
 	layout->addWidget(configBox, 1, 1);
@@ -1033,7 +1061,8 @@ DvbSConfigObject::DvbSConfigObject(QWidget *parent_, QBoxLayout *boxLayout, DvbM
 	for (int lnbNumber = 0; lnbNumber < 4; ++lnbNumber) {
 		DvbConfigBase *config;
 
-		if ((lnbConfig->configuration == DvbConfigBase::DiseqcSwitch) &&
+		if (((lnbConfig->configuration == DvbConfigBase::DiseqcSwitch) ||
+		     (lnbConfig->configuration == DvbConfigBase::NoDiseqc)) &&
 		    (lnbNumber < configs.size())) {
 			config = new DvbConfigBase(*configs.at(lnbNumber));
 		} else {
@@ -1042,14 +1071,24 @@ DvbSConfigObject::DvbSConfigObject(QWidget *parent_, QBoxLayout *boxLayout, DvbM
 
 		QPushButton *pushButton = new QPushButton(i18n("LNB %1 Settings", lnbNumber + 1),
 							  parent);
-		connect(this, SIGNAL(setDiseqcVisible(bool)), pushButton, SLOT(setVisible(bool)));
+		if (lnbNumber > 0)
+			connect(this, &DvbSConfigObject::setDiseqcVisible,
+				pushButton, &QPushButton::setVisible);
+		else
+			connect(this, &DvbSConfigObject::setFirstLnbVisible,
+				pushButton, &QPushButton::setVisible);
 		layout->addWidget(pushButton, lnbNumber + 2, 0);
 
 		QComboBox *comboBox = new QComboBox(parent);
 		comboBox->addItem(i18n("No Source"));
 		comboBox->addItems(sources);
 		comboBox->setCurrentIndex(sources.indexOf(config->scanSource) + 1);
-		connect(this, SIGNAL(setDiseqcVisible(bool)), comboBox, SLOT(setVisible(bool)));
+		if (lnbNumber > 0)
+			connect(this, &DvbSConfigObject::setDiseqcVisible,
+				comboBox, &QComboBox::setVisible);
+		else
+			connect(this, &DvbSConfigObject::setFirstLnbVisible,
+				comboBox, &QComboBox::setVisible);
 		layout->addWidget(comboBox, lnbNumber + 2, 1);
 
 		diseqcConfigs.append(DvbConfig(config));
@@ -1060,14 +1099,17 @@ DvbSConfigObject::DvbSConfigObject(QWidget *parent_, QBoxLayout *boxLayout, DvbM
 	// USALS rotor / Positions rotor
 
 	QPushButton *pushButton = new QPushButton(i18n("LNB Settings"), parent);
-	connect(this, SIGNAL(setRotorVisible(bool)), pushButton, SLOT(setVisible(bool)));
+
+	connect(this, &DvbSConfigObject::setRotorVisible, pushButton,
+		&QPushButton::setVisible);
 	layout->addWidget(pushButton, 6, 0);
 
 	lnbConfigs.append(new DvbSLnbConfigObject(timeoutBox, NULL, pushButton, lnbConfig, device));
 
 	sourceBox = new QComboBox(parent);
 	sourceBox->addItems(sources);
-	connect(this, SIGNAL(setRotorVisible(bool)), sourceBox, SLOT(setVisible(bool)));
+	connect(this, &DvbSConfigObject::setRotorVisible, sourceBox,
+		&QComboBox::setVisible);
 	layout->addWidget(sourceBox, 6, 1);
 
 	satelliteView = new QTreeWidget(parent);
@@ -1075,7 +1117,8 @@ DvbSConfigObject::DvbSConfigObject(QWidget *parent_, QBoxLayout *boxLayout, DvbM
 	// Usals rotor
 
 	pushButton = new QPushButton(i18n("Add Satellite"), parent);
-	connect(this, SIGNAL(setUsalsVisible(bool)), pushButton, SLOT(setVisible(bool)));
+	connect(this, &DvbSConfigObject::setUsalsVisible, pushButton,
+		&QPushButton::setVisible);
 	connect(pushButton, SIGNAL(clicked()), this, SLOT(addSatellite()));
 	layout->addWidget(pushButton, 7, 0, 1, 2);
 
@@ -1083,12 +1126,14 @@ DvbSConfigObject::DvbSConfigObject(QWidget *parent_, QBoxLayout *boxLayout, DvbM
 
 	rotorSpinBox = new QSpinBox(parent);
 	rotorSpinBox->setRange(0, 255);
-	connect(this, SIGNAL(setPositionsVisible(bool)), rotorSpinBox, SLOT(setVisible(bool)));
+	connect(this, &DvbSConfigObject::setPositionsVisible, rotorSpinBox,
+		&QSpinBox::setVisible);
 	layout->addWidget(rotorSpinBox, 8, 0);
 
 	pushButton = new QPushButton(i18n("Add Satellite"), parent);
+	connect(this, &DvbSConfigObject::setPositionsVisible, pushButton,
+		&QPushButton::setVisible);
 	connect(pushButton, SIGNAL(clicked()), this, SLOT(addSatellite()));
-	connect(this, SIGNAL(setPositionsVisible(bool)), pushButton, SLOT(setVisible(bool)));
 	layout->addWidget(pushButton, 8, 1);
 
 	// USALS rotor / Positions rotor
@@ -1112,7 +1157,8 @@ DvbSConfigObject::DvbSConfigObject(QWidget *parent_, QBoxLayout *boxLayout, DvbM
 	}
 
 	pushButton = new QPushButton(i18n("Remove Satellite"), parent);
-	connect(this, SIGNAL(setRotorVisible(bool)), pushButton, SLOT(setVisible(bool)));
+	connect(this, &DvbSConfigObject::setRotorVisible, pushButton,
+		&QPushButton::setVisible);
 	connect(pushButton, SIGNAL(clicked()), this, SLOT(removeSatellite()));
 	layout->addWidget(pushButton, 10, 0, 1, 2);
 
@@ -1125,47 +1171,55 @@ DvbSConfigObject::DvbSConfigObject(QWidget *parent_, QBoxLayout *boxLayout, DvbM
 
 	QLabel *label = new QLabel(i18n("Your position:"));
 	layout->addWidget(label);
-	connect(this, SIGNAL(setUsalsVisible(bool)), label, SLOT(setVisible(bool)));
+	connect(this, &DvbSConfigObject::setUsalsVisible, label,
+		&QLabel::setVisible);
 
 	label = new QLabel(i18n("Latitude:"));
 	layout->addWidget(label, 1, 0);
-	connect(this, SIGNAL(setUsalsVisible(bool)), label, SLOT(setVisible(bool)));
+	connect(this, &DvbSConfigObject::setUsalsVisible, label,
+		&QLabel::setVisible);
 
 	label = new QLabel(i18n("[S -90 ... 90 N]"));
 	layout->addWidget(label, 1, 1);
-	connect(this, SIGNAL(setUsalsVisible(bool)), label, SLOT(setVisible(bool)));
+	connect(this, &DvbSConfigObject::setUsalsVisible, label,
+		&QLabel::setVisible);
 
 	latitudeEdit = new QLineEdit(parent);
 	latitudeEdit->setText(QString::number(lnbConfig->latitude, 'g', 10));
 	connect(latitudeEdit, SIGNAL(textChanged(QString)), this, SLOT(latitudeChanged(QString)));
 	layout->addWidget(latitudeEdit, 1, 2);
-	connect(this, SIGNAL(setUsalsVisible(bool)), latitudeEdit, SLOT(setVisible(bool)));
+	connect(this, &DvbSConfigObject::setUsalsVisible, latitudeEdit,
+		&QLineEdit::setVisible);
 
 	latitudeValidLabel = new QLabel(parent);
 	latitudeValidLabel->setPixmap(validPixmap);
 	layout->addWidget(latitudeValidLabel, 1, 3);
-	connect(this, SIGNAL(setUsalsVisible(bool)), latitudeValidLabel, SLOT(setVisible(bool)));
+	connect(this, &DvbSConfigObject::setUsalsVisible, latitudeValidLabel,
+		&QLineEdit::setVisible);
 
 	label = new QLabel(i18n("Longitude:"));
 	layout->addWidget(label, 2, 0);
-	connect(this, SIGNAL(setUsalsVisible(bool)), label, SLOT(setVisible(bool)));
+	connect(this, &DvbSConfigObject::setUsalsVisible, label,
+		&QLabel::setVisible);
 
 	label = new QLabel(i18n("[W -180 ... 180 E]"));
 	layout->addWidget(label, 2, 1);
-	connect(this, SIGNAL(setUsalsVisible(bool)), label, SLOT(setVisible(bool)));
+	connect(this, &DvbSConfigObject::setUsalsVisible, label,
+		&QLabel::setVisible);
 
 	longitudeEdit = new QLineEdit(parent);
 	longitudeEdit->setText(QString::number(lnbConfig->longitude, 'g', 10));
 	connect(this, SIGNAL(setUsalsVisible(bool)), longitudeEdit, SLOT(setVisible(bool)));
-	connect(longitudeEdit, SIGNAL(textChanged(QString)),
-		this, SLOT(longitudeChanged(QString)));
+	connect(this, &DvbSConfigObject::setUsalsVisible, longitudeEdit,
+		&QLineEdit::setVisible);
 	layout->addWidget(longitudeEdit, 2, 2);
 
 	longitudeValidLabel = new QLabel(parent);
 	longitudeValidLabel->setPixmap(validPixmap);
 	layout->addWidget(longitudeValidLabel, 2, 3);
 	boxLayout->addLayout(layout);
-	connect(this, SIGNAL(setUsalsVisible(bool)), longitudeValidLabel, SLOT(setVisible(bool)));
+	connect(this, &DvbSConfigObject::setUsalsVisible, longitudeValidLabel,
+		&QLineEdit::setVisible);
 
 	configChanged(configBox->currentIndex());
 	connect(parent, SIGNAL(resetConfig()), this, SLOT(resetConfig()));
@@ -1238,8 +1292,13 @@ void DvbSConfigObject::appendConfigs(QList<DvbConfig> &list)
 {
 	int index = configBox->currentIndex();
 
-	if (index == 0) {
-		// Diseqc switch
+	if (index == 0 || index == 3) {
+		// Diseqc switch or No Diseqc
+
+		if (index == 3)
+			diseqcConfigs[0]->configuration = DvbConfigBase::NoDiseqc;
+		else
+			diseqcConfigs[0]->configuration = DvbConfigBase::DiseqcSwitch;
 
 		list += diseqcConfigs;
 	} else if ((index == 1) || (index == 2)) {
@@ -1289,6 +1348,7 @@ void DvbSConfigObject::configChanged(int index)
 		// Diseqc switch
 
 		emit setDiseqcVisible(true);
+		emit setFirstLnbVisible(true);
 		emit setRotorVisible(false);
 		emit setUsalsVisible(false);
 		emit setPositionsVisible(false);
@@ -1298,6 +1358,7 @@ void DvbSConfigObject::configChanged(int index)
 		satelliteView->hideColumn(1);
 
 		emit setDiseqcVisible(false);
+		emit setFirstLnbVisible(false);
 		emit setRotorVisible(true);
 		emit setUsalsVisible(true);
 		emit setPositionsVisible(false);
@@ -1311,9 +1372,18 @@ void DvbSConfigObject::configChanged(int index)
 		}
 
 		emit setDiseqcVisible(false);
+		emit setFirstLnbVisible(false);
 		emit setRotorVisible(true);
 		emit setUsalsVisible(false);
 		emit setPositionsVisible(true);
+	} else if (index == 3) {
+		// No Diseqc switch
+
+		emit setDiseqcVisible(false);
+		emit setFirstLnbVisible(true);
+		emit setRotorVisible(false);
+		emit setUsalsVisible(false);
+		emit setPositionsVisible(false);
 	}
 }
 
